#
# spec file for package python-Pygments
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Pygments
Version:        2.6.1
Release:        lp152.5.12.1
Summary:        A syntax highlighting package written in Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            http://pygments.org
Source:         https://files.pythonhosted.org/packages/source/P/Pygments/Pygments-%{version}.tar.gz
Patch1:         cve_2021_20270.patch
Patch2:         cve_2021_27291.patch
BuildRequires:  %{python_module base >= 3.5}
# We need pytest just because of its test runner, it seems even
# python3 stdlib unittest runner doesn't work
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-pygments = %{version}
Obsoletes:      python-pygments < %{version}
BuildArch:      noarch
%python_subpackages

%description
Pygments is a generic syntax highlighter for general use in all kinds of software
such as forum systems, wikis or other applications that need to prettify
source code. Highlights are:

 * a wide range of common languages and markup formats is supported
 * support for new languages and formats can be added
 * a number of output formats, presently HTML, LaTeX, RTF, SVG, all image
   formats that PIL supports and ANSI sequences
 * it is usable as a command-line tool and as a library
 * highlights Brainfuck

%prep
%setup -q -n Pygments-%{version}
%autopatch -p1

# Remove non-oss licensed files, see bnc# 760344
rm tests/examplefiles/firefox.mak tests/examplefiles/example.webidl

# Remove unnecessary shebang
sed -i '1 { /^#!/ d }' pygments/lexers/_usd_builtins.py

%build
%python_build

%install
%python_install
install -Dm0644 doc/pygmentize.1 %{buildroot}%{_mandir}/man1/pygmentize.1
%python_clone -a %{buildroot}%{_bindir}/pygmentize
%python_clone -a %{buildroot}%{_mandir}/man1/pygmentize.1
%{python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%fdupes %{buildroot}%{$python_sitelib}
}

%prepare_alternative pygmentize

%post
%{python_install_alternative pygmentize pygmentize.1}

%postun
%python_uninstall_alternative pygmentize

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGES
%python_alternative %{_bindir}/pygmentize
%python_alternative %{_mandir}/man1/pygmentize.1%{ext_man}
%{python_sitelib}/pygments/
%{python_sitelib}/Pygments-%{version}-py%{python_version}.egg-info/

%changelog
* Mon Nov 22 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Add cve_2021_27291.patch (CVE-2021-27291, bsc#1184812)
  + fix several exponential/cubic complexity regexes
* Fri Oct 15 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Add cve_2021_20270.patch (CVE-2021-20270, bsc#1183169)
  + fix infinite loop in SML lexer
* Thu Dec 31 2020 Gustavo Figueira <gfigueira@suse.com>
- Use %%python_uninstall_alternative in %%postun (bsc#1180252)
* Mon Dec 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Tue Apr 14 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Wed Mar 18 2020 Benoît Monin <benoit.monin@gmx.fr>
- fix the path of non-oss licensed files to remove
* Fri Mar 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- set the minimal version of python to 3.5 to match upstream
  requirement
* Mon Mar  9 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.6.1:
  * This release fixes a packaging issue. No functional changes.
- additional changes from version 2.6.0:
  * Running Pygments on Python 2.x is no longer supported.
  * Added lexers:
    + Linux kernel logs (PR#1310)
    + LLVM MIR (PR#1361)
    + MiniScript (PR#1397)
    + Mosel (PR#1287, PR#1326)
    + Parsing Expression Grammar (PR#1336)
    + ReasonML (PR#1386)
    + Ride (PR#1319, PR#1321)
    + Sieve (PR#1257)
    + USD (PR#1290)
    + WebIDL (PR#1309)
  * Updated lexers:
    + Apache2 (PR#1378)
    + Chapel (PR#1357)
    + CSound (PR#1383)
    + D (PR#1375, PR#1362)
    + Idris (PR#1360)
    + Perl6/Raku lexer (PR#1344)
    + Python3 (PR#1382, PR#1385)
    + Rust: Updated lexer to cover more builtins (mostly macros)
    and miscellaneous new syntax (PR#1320)
    + SQL: Add temporal support keywords (PR#1402)
  * The 256-color/true-color terminal formatters now support the
    italic attribute in styles (PR#1288)
  * Support HTTP 2/3 header (PR#1308)
  * Support missing reason in HTTP header (PR#1322)
  * Boogie/Silver: support line continuations and triggers, move
    contract keywords to separate category (PR#1299)
  * GAS: support C-style comments (PR#1291)
  * Fix names in S lexer (PR#1330, PR#1333)
  * Fix numeric literals in Ada (PR#1334)
  * Recognize .mjs files as Javascript (PR#1392)
  * Recognize .eex files as Elixir (PR#1387)
  * Fix re.MULTILINE usage (PR#1388)
  * Recognize pipenv and poetry dependency & lock files (PR#1376)
  * Improve font search on Windows (#1247)
  * Remove unused script block (#1401)
- disable python2 build: Pygments is python 3 only now
- remove shebang from pygments/lexers/_usd_builtins.py: unneeded
* Sun Dec  8 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.5.2:
  * Fix incompatibility with some setuptools versions (PR#1316)
  * Fix lexing of ReST field lists (PR#1279)
  * Fix lexing of Matlab keywords as field names (PR#1282)
  * Recognize double-quoted strings in Matlab (PR#1278)
  * Avoid slow backtracking in Vim lexer (PR#1312)
  * Fix Scala highlighting of types (PR#1315)
  * Highlight field lists more consistently in ReST (PR#1279)
  * Fix highlighting Matlab keywords in field names (PR#1282)
  * Recognize Matlab double quoted strings (PR#1278)
  * Add some Terraform keywords
  * Update Modelica lexer to 3.4
  * Update Crystal examples
- additional changes from version 2.5.1:
  * This release fixes a packaging issue. No functional changes.
- additional changes from version 2.5.0:
  * Added lexers:
    + Email (PR#1246)
    + Erlang, Elxir shells (PR#823, #1521)
    + Notmuch (PR#1264)
    + Scdoc (PR#1268)
    + Solidity (#1214)
    + Zeek (new name for Bro) (PR#1269)
    + Zig (PR#820)
  * Updated lexers:
    + Apache2 Configuration (PR#1251)
    + Bash sessions (#1253)
    + CSound (PR#1250)
    + Dart
    + Dockerfile
    + Emacs Lisp
    + Handlebars (PR#773)
    + Java (#1101, #987)
    + Logtalk (PR#1261)
    + Matlab (PR#1271)
    + Praat (PR#1277)
    + Python3 (PR#1255)
    + Ruby
    + YAML (#1528)
    + Velocity
  * Added styles:
    + Inkpot (PR#1276)
  * The PythonLexer class is now an alias for the former
    Python3Lexer. The old PythonLexer is available as Python2Lexer.
  * Bump NasmLexer priority over TasmLexer for .asm files
    (fixes #1326)
  * Default font in the ImageFormatter has been updated
    (#928, PR#1245)
  * Test suite switched to py.test, removed nose dependency (#1490)
  * Reduce TeraTerm lexer score -- it used to match nearly all
    languages (#1256)
  * Treat Skylark/Starlark files as Python files (PR#1259)
  * Image formatter: actually respect line_number_separator option
  * Add LICENSE file to wheel builds
  * Agda: fix lambda highlighting
  * Dart: support @ annotations
  * Dockerfile: accept FROM ... AS syntax
  * Emacs Lisp: add more string functions
  * GAS: accept registers in directive arguments
  * Java: make structural punctuation (braces, parens, colon,
    comma) Punctuation, not Operator (#987)
  * Java: support var contextual keyword (#1101)
  * Matlab: Fix recognition of function keyword (PR#1271)
  * Python: recognize .jy filenames (#976)
  * Python: recognize f string prefix (#1156)
  * Ruby: support squiggly heredocs
  * Shell sessions: recognize Virtualenv prompt (PR#1266)
  * Velocity: support silent reference syntax
- drop denose.patch: fixed upstream
- fix postuninstall alternative
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.2:
  - Fix encoding error when guessing lexer with given ``encoding`` option
    (#1438)
  - Updated lexers:
  * Coq (#1430)
  * MSDOS Session (PR#734)
  * NASM (#1517)
  * Objective-C (PR#813, #1508)
  * Prolog (#1511)
  * TypeScript (#1515)
  - Support CSS variables in stylesheets (PR#814, #1356)
  - Fix F# lexer name (PR#709)
  - Fix ``TerminalFormatter`` using bold for bright text (#1480)
* Mon May 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.4.0
  * Add solarized style
  * Add support for Markdown reference-style links
  * Add license information to generated HTML/CSS files
  * Change ANSI color names
  * Fix catastrophic backtracking in the bash lexer
  * Fix documentation failing to build using Sphinx 2.0
  * Fix incorrect links in the Lisp and R lexer documentation
  * Fix rare unicode errors on Python 2.7
  * Fix lexers popping from an empty stack
  * TypoScript uses .typoscript now
  * Updated Trove classifiers and pip requirements
* Mon Apr  1 2019 Matej Cepl <mcepl@suse.com>
- Refresh denose.patch to make whole test suite to pass.
  bt#birkenfeld/pygments-main#1490
* Mon Feb 11 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name in summary (rpmlint).
- Ensure neutrality of description.
* Mon Feb 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.1:
  * Update lexers
  * Minimum Python versions changed to 2.7 and 3.5
  * Added support for Python 3.7 generator changes (PR#772)
  * Fix incorrect token type in SCSS for single-quote strings (#1322)
  * Use `terminal256` formatter if `TERM` contains `256` (PR#666)
  * Fix incorrect handling of GitHub style fences in Markdown (PR#741, #1389)
  * Fix `%%a` not being highlighted in Python3 strings (PR#727)
- Drop patch python_37.diff which was merged upstream
- Refresh patch denose.patch
* Thu Jan 10 2019 Matej Cepl <mcepl@suse.com>
- Added denose.patch removing dependency on the nose package.
  https://bitbucket.org/birkenfeld/pygments-main/issues/1490/remove-nose-dependency
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul 16 2018 mimi.vx@gmail.com
- add python_37.diff  - fixes build with python-3.7+
* Tue Aug 15 2017 dmueller@suse.com
- fix build in a python2.x only env
* Fri Apr  7 2017 toddrme2178@gmail.com
- Use https url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update source url.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Update to 2.2.0
  - Added the ability to load lexer and formatter classes directly from files
    with the `-x` command line option and the `lexers.load_lexer_from_file()`
    and `formatters.load_formatter_from_file()` functions. (PR#559)
  - Added `lexers.find_lexer_class_by_name()`. (#1203)
  - Added new token types and lexing for magic methods and variables in Python
    and PHP.
  - Added a new token type for string affixes and lexing for them in Python, C++
    and Postgresql lexers.
  - Added a new token type for heredoc (and similar) string delimiters and
    lexing for them in C++, Perl, PHP, Postgresql and Ruby lexers.
  - Styles can now define colors with ANSI colors for use in the 256-color
    terminal formatter. (PR#531)
  - Improved the CSS lexer. (#1083, #1130)
  - Added "Rainbow Dash" style. (PR#623)
  - Delay loading `pkg_resources`, which takes a long while to import. (PR#690)
* Wed Apr  5 2017 tbechtold@suse.com
- Fix python_module macro definition
* Thu Dec  8 2016 jmatejek@suse.com
- update for multipython build
- only distribute "pygmentize" for Python 3
* Mon Oct 17 2016 dmueller@suse.com
- update to 2.1.3:
  - Fixed regression in Bash lexer (PR#563)
  - Fixed Python 3 regression in image formatter (#1215)
  - Fixed regression in Bash lexer (PR#562)
* Sun Feb 14 2016 michael@stroeder.com
- Update to version 2.1.1
  - Fixed Jython compatibility (#1205)
  - Fixed HTML formatter output with leading empty lines (#1111)
  - Added a mapping table for LaTeX encodings and added utf8 (#1152)
  - Fixed image formatter font searching on Macs (#1188)
  - Fixed deepcopy-ing of Token instances (#1168)
  - Fixed Julia string interpolation (#1170)
  - Fixed statefulness of HttpLexer between get_tokens calls
  - Many smaller fixes to various lexers
* Tue Feb  9 2016 olaf@aepfle.de
- Disable testsuite in SLE_11 because it requires python 2.7
* Mon Jan 25 2016 michael@stroeder.com
- Update to version 2.1
  - Added styles:
  * Lovelace (PR#456)
  * Algol and Algol-nu (#1090)
  - Added formatters:
  * IRC (PR#458)
  * True color (24-bit) terminal ANSI sequences (#1142)
    (formatter alias: "16m")
  - New "filename" option for HTML formatter (PR#527).
  - Improved performance of the HTML formatter for long lines (PR#504).
  - Updated autopygmentize script (PR#445).
  - Fixed style inheritance for non-standard token types in HTML output.
  - Added support for async/await to Python 3 lexer.
  - Rewrote linenos option for TerminalFormatter (it's better, but slightly
    different output than before) (#1147).
  - Javascript lexer now supports most of ES6 (#1100).
  - Cocoa builtins updated for iOS 8.1 (PR#433).
  - Combined BashSessionLexer and ShellSessionLexer, new version should support
    the prompt styles of either.
  - Added option to pygmentize to show a full traceback on exceptions.
  - Fixed incomplete output on Windows and Python 3 (e.g. when using iPython
    Notebook) (#1153).
  - Allowed more traceback styles in Python console lexer (PR#253).
  - Added decorators to TypeScript (PR#509).
  - Fix highlighting of certain IRC logs formats (#1076).
* Wed Mar 11 2015 tbehrens@suse.com
- Update to version 2.0.2:
  * Fix Python tracebacks getting duplicated in the console lexer
  * Backquote-delimited identifiers are now recognized in F#
  * Fix an encoding issue when using pygmentize with the -o option.
  * Default lexer encoding is now “guess”
  * Major update to Swift lexer.
  * Multiple fixes to lexer guessing in conflicting cases
  * Simplified regexes and builtin lists.
  * Dropped Python 2.4 and 2.5 compatibility
  * Lexers added:
    APL (#969)
    Agda and Literate Agda (PR#203)
    Alloy (PR#355)
    AmbientTalk
    BlitzBasic (PR#197)
    ChaiScript (PR#24)
    Chapel (PR#256)
    Cirru (PR#275)
    Clay (PR#184)
    ColdFusion CFC (PR#283)
    Cryptol and Literate Cryptol (PR#344)
    Cypher (PR#257)
    Docker config files
    EBNF (PR#193)
    Eiffel (PR#273)
    GAP (PR#311)
    Golo (PR#309)
    Handlebars (PR#186)
    Hy (PR#238)
    Idris and Literate Idris (PR#210)
    Igor Pro (PR#172)
    Inform 6/7 (PR#281)
    Intel objdump (PR#279)
    Isabelle (PR#386)
    Jasmin (PR#349)
    JSON-LD (PR#289)
    Kal (PR#233)
    Lean (PR#399)
    LSL (PR#296)
    Limbo (PR#291)
    Liquid (#977)
    MQL (PR#285)
    MaskJS (PR#280)
    Mozilla preprocessors
    Mathematica (PR#245)
    NesC (PR#166)
    Nit (PR#375)
    Nix (PR#267)
    Pan
    Pawn (PR#211)
    Perl 6 (PR#181)
    Pig (PR#304)
    Pike (PR#237)
    QBasic (PR#182)
    Red (PR#341)
    ResourceBundle (#1038)
    Rexx (PR#199)
    Rql (PR#251)
    Rsl
    SPARQL (PR#78)
    Slim (PR#366)
    Swift (PR#371)
    Swig (PR#168)
    TADS 3 (PR#407)
    Todo.txt todo lists
    Twig (PR#404)
  * Added a helper to “optimize” regular expressions
  * New styles: “xcode” and “igor”
  * The command-line “pygmentize” tool now tries a little harder
  * Added “inencoding” option for lexers to override “encoding”
  * Added line-by-line “streaming” mode for pygmentize with the “-s” option
  * Added an “envname” option to the LaTeX formatter to select a replacement
  * Updated the Makefile lexer to yield a little more useful highlighting.
  * Lexer aliases passed to get_lexer_by_name() are now case-insensitive.
  * File name matching in lexers and formatters will now use a regex cache for speed
  * Pygments will now recognize “vim” modelines when guessing the lexer
  * Major restructure of the pygments.lexers module namespace.
  * The NameHighlightFilter now works with any Name.* token type (#790).
  * Python 3 lexer: add new exceptions from PEP 3151.
  * Opa lexer: add new keywords (PR#170).
  * Julia lexer: add keywords and underscore-separated number literals
  * Lasso lexer: fix method highlighting, update builtins
  * Objective C/C++ lexers: allow “@” prefixing any expression (#871).
  * Ruby lexer: fix lexing of Name::Space tokens (#860) and of symbols in hashes
  * Stan lexer: update for version 2.4.0 of the language
  * JavaScript lexer: add the “yield” keyword (PR#196).
  * HTTP lexer: support for PATCH method (PR#190).
  * Koka lexer: update to newest language spec (PR#201).
  * Haxe lexer: rewrite and support for Haxe 3 (PR#174).
  * Prolog lexer: add different kinds of numeric literals
  * F# lexer: rewrite with newest spec for F# 3.0 (#842), fix a bug with dotted chains
  * Kotlin lexer: general update (PR#271).
  * Rebol lexer: fix comment detection and analyse_text (PR#261).
  * LLVM lexer: update keywords to v3.4 (PR#258).
  * PHP lexer: add new keywords and binary literals (PR#222).
  * external/markdown-processor.py updated to newest python-markdown
  * CSS lexer: some highlighting order fixes (PR#231).
  * Ceylon lexer: fix parsing of nested multiline comments (#915).
  * C family lexers: fix parsing of indented preprocessor directives
  * Rust lexer: update to 0.9 language version (PR#270, PR#388).
  * Elixir lexer: update to 0.15 language version (PR#392).
  * Fix swallowing incomplete tracebacks in Python console lexer
* Mon Apr  7 2014 dmueller@suse.com
- add LICENSE to doc section
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May  3 2013 toddrme2178@gmail.com
- Update to version 1.6:
  - Lexers added
  - Fix unquoted HTML attribute lexing in Opa .
  - The HTML formatter now supports linking to tags using CTags files, when the
    python-ctags package is installed .
  - The HTML formatter now has a "linespans" option that wraps every line in a
    <span> tag with a specific id .
  - When deriving a lexer from another lexer with token definitions, definitions
    for states not in the child lexer are now inherited.  If you override a state
    in the child lexer, an "inherit" keyword has been added to insert the base
    state at that position .
  - The C family lexers now inherit token definitions from a common base class,
    removing code duplication .
  - Use "colorama" on Windows for console color output .
  - Fix Template Haskell highlighting .
  - Fix some S/R lexer errors .
  - Fix a bug in the Prolog lexer with names that start with 'is' .
  - Rewrite Dylan lexer, add Dylan LID lexer .
  - Add a Java quickstart document .
  - Add a "external/autopygmentize" file that can be used as .lessfilter .
* Thu May  3 2012 toddrme2178@gmail.com
- Removed files with non-oss license, see bnc#760344
- Cleanups in python 2 and python 3 spec files
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 1.5:
  - Fix Python 3 terminal highlighting with pygmentize
  - In the LaTeX formatter, escape special &, < and > chars
  - In the LaTeX formatter, fix display problems for styles with token
    background colors
  - Enhancements to the Squid conf lexer
  - Several fixes to the reStructuredText lexer
  - Recognize methods in the ObjC lexer
  - Fix Lua "class" highlighting: it does not have classes
  - Fix degenerate regex in Scala lexer  and highlighting bugs
  - Fix number pattern order in Ocaml lexer
  - Fix generic type highlighting in ActionScript 3
  - Fixes to the Clojure lexer
  - Fix degenerate regex in Nemerle lexer
  - Fix infinite looping in CoffeeScript lexer
  - Fix crashes and analysis with ObjectiveC lexer
  - Add some Fortran 2003 keywords.
  - Fix Boo string regexes
  - Add "rrt" style
  - Fix infinite looping in Darcs Patch lexer.
  - Lots of misc fixes to character-eating bugs and ordering problems in many
    different lexers.
* Tue Jan 24 2012 bwiedemann@suse.com
- fix Obsoletes
* Fri Sep 23 2011 saschpe@suse.de
- Disable tests again, breaks i586 build
* Thu Sep 22 2011 saschpe@suse.de
- Fixed license to BSD-2-Clause
* Sun Sep 11 2011 saschpe@gmx.de
- Change license to BSD-3-Clause (SPDX style)
- Removed %%clean section (has sane default)
- Added python-distribute requirement
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Pygments', obsoletes 'python-pygments'
* Mon Feb 21 2011 nix@opensuse.org
- Update to version 1.4
- Compress the tarball with bz2
* Tue Sep 14 2010 coolo@novell.com
- correct email addresses
* Fri Jun 18 2010 coolo@novell.com
- update to 1.3.1 (1.4 is too late, but is known to fix
  http://dev.pocoo.org/projects/pygments/ticket/507 )
* Fri Feb 12 2010 bitdealer@opensuse.org
- Updated to 1.2.2
* Fri Oct  9 2009 bitdealer@opensuse.org
- Updated to 1.1.1
* Tue Dec  9 2008 cfarrell1980@gmail.com
- Updated to version 1.0
* Thu Jun 21 2007 judas_iscariote@shorewall.net
- Initial package version.
